==> haskell-sourcemap-0.1.7-194-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sourcemap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sourcemap
version:              0.1.7
visibility:           public
id:                   sourcemap-0.1.7-Lp1bQOX2ppGKLraUEVxz90
key:                  sourcemap-0.1.7-Lp1bQOX2ppGKLraUEVxz90
license:              BSD-3-Clause
copyright:            2012 Chris Done
maintainer:           Jens Petersen <juhpetersen@gmail.com>
author:               Chris Done
stability:            alpha
synopsis:
    Implementation of source maps as proposed by Google and Mozilla.

description:
    Implementation of source maps, revision 3, proposed by Google and Mozilla here
    <https://wiki.mozilla.org/DevTools/Features/SourceMap> and here
    <https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit>

category:             Development
abi:                  5aa189891705c0f98b7739cbd5f7b292
exposed:              True
exposed-modules:      SourceMap SourceMap.Types
hidden-modules:       VLQ
import-dirs:          /usr/lib/ghc-9.4.8/site-local/sourcemap-0.1.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/sourcemap-0.1.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/sourcemap-0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sourcemap
hs-libraries:         HSsourcemap-0.1.7-Lp1bQOX2ppGKLraUEVxz90
depends:
    aeson-2.1.2.1-G4Y2VMvw6jlHlUlOzfqhge
    attoparsec-0.14.4-8RYxJQa7MEjKmC3I11Us4k base-4.17.2.1
    bytestring-0.11.5.3 process-1.6.18.0 text-2.0.2
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:   /usr/share/doc/haskell-sourcemap/html/sourcemap.haddock
haddock-html:         /usr/share/doc/haskell-sourcemap/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sourcemap-0.1.7-196-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sourcemap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sourcemap
version:              0.1.7
visibility:           public
id:                   sourcemap-0.1.7-D8oegSD6BAlBmuUQ9x00Zg
key:                  sourcemap-0.1.7-D8oegSD6BAlBmuUQ9x00Zg
license:              BSD-3-Clause
copyright:            2012 Chris Done
maintainer:           Jens Petersen <juhpetersen@gmail.com>
author:               Chris Done
stability:            alpha
synopsis:
    Implementation of source maps as proposed by Google and Mozilla.

description:
    Implementation of source maps, revision 3, proposed by Google and Mozilla here
    <https://wiki.mozilla.org/DevTools/Features/SourceMap> and here
    <https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit>

category:             Development
abi:                  323f5708fd92898fe6c74c3e47d05672
exposed:              True
exposed-modules:      SourceMap SourceMap.Types
hidden-modules:       VLQ
import-dirs:          /usr/lib/ghc-9.4.8/site-local/sourcemap-0.1.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/sourcemap-0.1.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/sourcemap-0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sourcemap
hs-libraries:         HSsourcemap-0.1.7-D8oegSD6BAlBmuUQ9x00Zg
depends:
    aeson-2.1.2.1-Ex7WnNUT1auEGSF1Md5zyM
    attoparsec-0.14.4-4lxImiie977LVZ07Q4RuOa base-4.17.2.1
    bytestring-0.11.5.3 process-1.6.18.0 text-2.0.2
    unordered-containers-0.2.20-EFINKuAnn2VCsrMAVqSNI6
    utf8-string-1.0.2-7x3IoasPx5wHP6oJo1JvJP

haddock-interfaces:   /usr/share/doc/haskell-sourcemap/html/sourcemap.haddock
haddock-html:         /usr/share/doc/haskell-sourcemap/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
